Method: KeepassKpscript::Kpscript#open

Defined in:
lib/keepass_kpscript/kpscript.rb

#open(database_file, password: nil, password_enc: nil, key_file: nil) ⇒ Object

Open a database using this KPScript instance. At least 1 of password, password_enc or key_file is mandatory.

Parameters
  • database_file (String): Path to the database file

  • password (String, SecretString or nil): Password opening the database, or nil if none [default: nil].

  • password_enc (String, SecretString or nil): Encrypted password opening the database, or nil if none [default: nil].

  • key_file (String, SecretString or nil): Key file path opening the database, or nil if none [default: nil].

Result
  • Database: The database



32
33
34
# File 'lib/keepass_kpscript/kpscript.rb', line 32

def open(database_file, password: nil, password_enc: nil, key_file: nil)
  Database.new(self, database_file, password: password, password_enc: password_enc, key_file: key_file)
end